@@ -208,6 +208,8 @@ public:
 	static void dump(FILE *fp, keynode *node, unsigned level);
 	static void snapshot(const char *uid);
 	static void dumpfile(const char *uid);
+	static void history(const char *uid);
+	static void siplog(const char *uid);
 	static bool period(long slice);
 	static void result(const char *value);
 	static FILE *open(const char *uid = NULL, const char *cfgpath = NULL);
