@@ -295,16 +295,14 @@ static struct passwd *getuserenv(const char *uid, const char *cfgfile)
 	}
 
 	if(uid) {
-		setenv("PWD", pwd->pw_dir, 1);
-		fsys::createDir(pwd->pw_dir, 0770);
-		if(!fsys::changeDir(pwd->pw_dir)) {
-			fsys::createDir(DEFAULT_VARPATH "/lib/sipwitch", 0775);
-			if(fsys::changeDir(DEFAULT_VARPATH "/lib/sipwitch"))
-				setenv("PWD", DEFAULT_VARPATH "/lib/sipwitch", 1);
-			else {
-				fsys::changeDir(buf);			
+		fsys::createDir(DEFAULT_VARPATH "/lib/sipwitch", 0775);
+		if(fsys::changeDir(DEFAULT_VARPATH "/lib/sipwitch") == 0)
+			setenv("PWD", DEFAULT_VARPATH "/lib/sipwitch", 1);
+		else {
+			if(pwd && fsys::changeDir(pwd->pw_dir) == 0)
+				setenv("PWD", pwd->pw_dir, 1);
+			else
 				setenv("PWD", buf, 1);
-			}
 		}
 	}
 	else {
